@@ -2,7 +2,7 @@ from .utils import (hierarchical_path, columns_with_distinct_values,
                     create_pairs,
                     column_use,
                     figures_to_html)
-from datamallet.tabular.utils import (check_dataframe,
+from datamallet.tabular.utils import (check_dataframe,check_numeric, check_columns,
                                       extract_numeric_cols,
                                       calculate_correlation)
 import pandas as pd
@@ -19,7 +19,9 @@ def create_pie(df,
     Creates a pie chart for every categorical variable in the dataset.
     :param df: pandas dataframe,
     :param numeric_cols: list of columns with numeric data
-    :param list_of_categorical_columns:list of column names which have categorical data
+    :param list_of_categorical_columns:list of column names which have categorical data.
+            Output of function columns_with_distinct_values(df=self.df, categorical_only=True,
+                                                        maximum_number_distinct_values=maximum_number_sectors)
     :param create_html:boolean, whether the figures should be converted to HTML or not
     :param hole:boolean, hole in the pie chart
     :param filename:str, a suitable name for the produced html file, exclude the extension
@@ -30,18 +32,24 @@ def create_pie(df,
     assert isinstance(create_html, bool), "create_html must be a boolean"
     assert isinstance(hole, bool), "hole must be a boolean"
     assert isinstance(filename, str), "filename must be a string with a dot or an extension"
+    assert len(list_of_categorical_columns) != 0, "list_of_categorical_columns must not be empty"
+    assert len(numeric_cols) != 0, "numeric_cols must not be empty"
+    assert isinstance(df, pd.DataFrame), "df must be a pandas dataframe"
+    assert '.' not in filename, "filename doesn't need an extension"
 
     figure_list = list()
 
-    for value in numeric_cols:
-        for name in list_of_categorical_columns:
-            plot = px.pie(names=name,
-                          data_frame=df,
-                          values=value,
-                          hole=hole,
-                          title='Pie chart showing distribution of {} across {} segments'.format(value, name))
+    if check_numeric(df=df,column_list=numeric_cols) and check_columns(df=df,column_list=numeric_cols):
 
-            figure_list.append(plot)
+        for value in numeric_cols:
+            for name in list_of_categorical_columns:
+                plot = px.pie(names=name,
+                              data_frame=df,
+                              values=value,
+                              hole=hole,
+                              title='Pie chart showing distribution of {} across {} segments'.format(value, name))
+
+                figure_list.append(plot)
 
     if create_html:
         figures_to_html(figs=figure_list, filename=filename)
